@@ -634,6 +634,17 @@ css_parser_parse_value (const gchar *buffer, gint start_pos, gint end_pos, CssVa
 			css_value_list_append (list, term, list_sep);
 		
 		pos = css_parser_parse_whitespace (buffer, pos, end_pos);
+
+		if (pos == end_pos) {
+			/* Unfinished list : work-around */
+			if (n == 1)
+				*ret_val = term;
+			else {
+				css_value_list_append (list, term, 0);
+				*ret_val = list;
+			}
+			return pos;
+		}
 	}
 
 	return pos;
