@@ -40,6 +40,7 @@
 
 enum {
 	REQUEST_URL,
+	REQUEST_ICON,
 	LINK_CLICKED,
 	SET_BASE,
 	TITLE_CHANGED,
@@ -64,6 +65,13 @@ enum {
 	LAST_SIGNAL
 };
 
+typedef struct _RefreshData RefreshData;
+
+struct _RefreshData {
+	HtmlDocument *doc;
+	gchar *url;
+};
+
 static GObjectClass *parent_class = NULL;
 
 
@@ -146,6 +154,21 @@ html_document_stylesheet_stream_close (const gchar *buffer, gint len, gpointer d
 	g_signal_emit (G_OBJECT (document), document_signals [STYLE_UPDATED], 0, DOM_NODE (dom_Document__get_documentElement (document->dom_document)), style_change);
 }
 
+static gboolean
+html_document_refresh_timeout (gpointer data)
+{
+	RefreshData *rdata = (RefreshData *) data;
+
+	g_signal_emit (G_OBJECT (rdata->doc), document_signals [LINK_CLICKED],
+		       0, rdata->url);
+
+	g_free (rdata->url);
+	g_object_unref (rdata->doc);
+	g_free (rdata);
+
+	return FALSE;
+}
+
 static void
 html_document_node_inserted_traverser (HtmlDocument *document, DomNode *node)
 {
@@ -166,11 +189,52 @@ html_document_node_inserted_traverser (HtmlDocument *document, DomNode *node)
 					HtmlStream *stream = html_stream_buffer_new (html_document_stylesheet_stream_close, document);
 
 					g_signal_emit (G_OBJECT (document), document_signals [REQUEST_URL], 0, url, stream);
-					xmlFree (url);
 				}
+				g_free (url);
+			} else if (str && (strcasecmp (str, "icon") == 0)) {
+				gchar *url = xmlGetProp (node->xmlnode, "href");
+				if (url) {
+					g_signal_emit (G_OBJECT (document), document_signals [REQUEST_ICON], 0, url);
+				}
+				g_free (url);
 			}
-			if (str)
-				xmlFree (str);
+			g_free (str);
+		}
+		else if (strcasecmp (node->xmlnode->name, "meta") == 0) {
+			gchar *str = xmlGetProp (node->xmlnode, "http-equiv");
+
+			if (str && (strcasecmp (str, "content-type") == 0)) {
+			} else if (str && (strcasecmp (str, "refresh") == 0)) {
+				RefreshData *rdata;
+				gchar *content = xmlGetProp (node->xmlnode, "content");
+				gchar *timestr;
+				gchar *url;
+				gint timeval;
+
+				rdata = g_new0 (RefreshData, 1);
+				rdata->doc = g_object_ref (document);
+
+				if (strchr (content, ';')) {
+					timestr = g_strndup (content, strlen (content) - strlen (strchr (content, ';')));
+				} else {
+					timestr = g_strdup (content);
+				}
+				timeval = atoi (timestr);
+
+				if (strchr (content, '=')) {
+					url = g_strndup (content + (strlen (content) - strlen (strchr (content, '=')) + 1), strlen (strchr (content, '=')) + 1);
+				} else {
+					url = g_strdup ("");
+				}
+				rdata->url = g_strdup (url);
+
+				g_timeout_add (timeval * 1000, (GSourceFunc) html_document_refresh_timeout, rdata);
+
+				g_free (url);
+				g_free (timestr);
+				g_free (content);
+			}
+			g_free (str);
 		}
 		else if (node->xmlnode->type == XML_TEXT_NODE && node->xmlnode->parent && strcasecmp (node->xmlnode->parent->name, "option") == 0) {
 			dom_html_option_element_new_character_data (DOM_HTML_OPTION_ELEMENT (dom_Node__get_parentNode (node)));
@@ -447,6 +511,17 @@ html_document_class_init (HtmlDocumentClass *klass)
 			      G_TYPE_STRING,
 			      HTML_TYPE_STREAM);
 
+	document_signals [REQUEST_ICON] =
+		g_signal_new ("request_icon",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (HtmlDocumentClass, request_icon),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__STRING,
+			      G_TYPE_NONE,
+			      1,
+			      G_TYPE_STRING);
+
 	document_signals [LINK_CLICKED] =
 		g_signal_new ("link_clicked",
 			      G_TYPE_FROM_CLASS (object_class),
