@@ -1990,6 +1990,10 @@ html_view_removed (HtmlDocument *document, DomNode *node, HtmlView *view)
 		html_box_set_unrelayouted_up (box->parent);		
 
 	if (box) {
+		/* Clear the selection first*/
+		if (view->sel_list)
+			html_selection_clear (view);
+
 		if (box->children)
 			html_view_layout_tree_free (view, box->children);
 
